summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/Plugin.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/Plugin.java')
-rw-r--r--kdejava/koala/org/kde/koala/Plugin.java18
1 files changed, 9 insertions, 9 deletions
diff --git a/kdejava/koala/org/kde/koala/Plugin.java b/kdejava/koala/org/kde/koala/Plugin.java
index d6cd3ae8..af4fb0af 100644
--- a/kdejava/koala/org/kde/koala/Plugin.java
+++ b/kdejava/koala/org/kde/koala/Plugin.java
@@ -145,25 +145,25 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
to get the action object.
@short Retrieves an action of the client by name.
*/
- public native KAction action(String name);
+ public native TDEAction action(String name);
/**
Retrieves an action for a given TQDomElement. The default
implementation uses the "name" attribute to query the action
object via the other action() method.
@short Retrieves an action for a given TQDomElement.
*/
- public native KAction action(TQDomElement element);
+ public native TDEAction action(TQDomElement element);
/**
Retrieves the entire action collection for the GUI client. If
you subclass KXMLGUIClient you should call
- KActionCollection.setWidget( TQWidget ) with this object, or
- you will encounter subtle bugs with KAction keyboard shortcuts.
- This is not necessary if your KXMLGUIClient is a KMainWindow.
+ TDEActionCollection.setWidget( TQWidget ) with this object, or
+ you will encounter subtle bugs with TDEAction keyboard shortcuts.
+ This is not necessary if your KXMLGUIClient is a TDEMainWindow.
@short Retrieves the entire action collection for the GUI client.
- @see KActionCollection#setWidget(
+ @see TDEActionCollection#setWidget(
@see #org#kde#qt#TQWidget*
*/
- public native KActionCollection actionCollection();
+ public native TDEActionCollection actionCollection();
/**
@return The instance ( TDEInstance ) for this GUI client.
@@ -271,7 +271,7 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
This tag will get expanded to a list of actions. In the example
above ( a file manager with a dynamic file menu ), you would call
<pre>
- TQPtrList<KAction> file_actions;
+ TQPtrList<TDEAction> file_actions;
for( ... )
if( ... )
file_actions.append( cool_action );
@@ -287,7 +287,7 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
menu too..
@short ActionLists are a way for XMLGUI to support dynamic lists of actions.
*/
// void plugActionList(const TQString& arg1,const TQPtrList<KAction>& arg2); >>>> NOT CONVERTED
/**
The complement of plugActionList() ...
@short The complement of plugActionList() .
@@ -287,7 +287,7 @@ public class Plugin extends TQObject implements KXMLGUIClientInterface {
*/
- // void plugActionList(const TQString& arg1,const TQPtrList<KAction>& arg2); >>>> NOT CONVERTED
+ // void plugActionList(const TQString& arg1,const TQPtrList<TDEAction>& arg2); >>>> NOT CONVERTED
/**
The complement of plugActionList() ...